==> ejc-salary-impl-3.0.0-20241128.021400-65-sources.jar: com/ejianc/business/salary/controller/JspayableSourceController.java <==
package com.ejianc.business.salary.controller;

import java.io.Serializable;

import com.baomidou.mybatisplus.core.conditions.update.UpdateWrapper;
import com.ejianc.business.salary.bean.PayableDetailEntity;
import com.ejianc.business.salary.bean.TaxDetailEntity;
import com.ejianc.business.salary.bean.TaxEntity;
import com.ejianc.business.salary.service.*;
import com.ejianc.business.salary.vo.SourceDetailVO;
import com.ejianc.foundation.orgcenter.vo.OrgVO;
import com.ejianc.foundation.support.vo.BillCodeParam;
import com.ejianc.foundation.support.api.IBillCodeApi;
import com.ejianc.foundation.support.api.IBillTypeApi;
import com.ejianc.framework.core.exception.BusinessException;
import com.ejianc.framework.core.util.ExcelExport;
import org.apache.commons.lang3.StringUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import java.math.BigDecimal;
import java.text.DateFormat;
import java.text.ParseException;
import java.text.SimpleDateFormat;
import java.util.*;
import java.util.stream.Collectors;
import com.alibaba.fastjson.JSONObject;
import org.springframework.stereotype.Controller;
import org.springframework.web.bind.annotation.*;
import org.apache.commons.collections.CollectionUtils;
import javax.servlet.http.HttpServletResponse;

import com.ejianc.foundation.orgcenter.api.IOrgApi;
import com.ejianc.framework.core.response.CommonResponse;
import org.springframework.beans.factory.annotation.Autowired;
import com.ejianc.framework.core.context.InvocationInfoProxy;
import com.ejianc.framework.core.kit.mapper.BeanMapper;
import com.ejianc.framework.core.kit.collection.ListUtil;
import com.ejianc.framework.auth.session.SessionManager;
import com.ejianc.framework.auth.session.UserContext;

import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.ejianc.framework.core.response.Parameter;
import com.ejianc.framework.core.response.QueryParam;

import com.ejianc.business.salary.bean.JspayableSourceEntity;
import com.ejianc.business.salary.vo.JspayableSourceVO;

/**
 * 应发工资明细来源
 *
 * @author generator
 *
 */
@Controller
@RequestMapping("jspayableSource")
public class JspayableSourceController implements Serializable {
	private static final long serialVersionUID = 1L;

    private Logger logger = LoggerFactory.getLogger(this.getClass());

    @Autowired
    private IBillTypeApi billTypeApi;
    @Autowired
    private IBillCodeApi billCodeApi;
    @Autowired
    private IOrgApi iOrgApi;

    private static final String BILL_CODE = "Invoice_Open_Apply_Code";//此处需要根据实际修改

    @Autowired
    private IJspayableSourceService service;

    @Autowired
    private SessionManager sessionManager;



    @Autowired
    private IJspayableService jspayableService;

    @Autowired
    private IPayableDetailService payableDetailService;
    @Autowired
    private ITaxService taxService;
    @Autowired
    private ITaxDetailService taxDetailService;
    @Autowired
    private PayableController payableController;

    /**
     * @Description saveOrUpdate 新增或者修改
     */
    @RequestMapping(value = "/saveOrUpdate", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<JspayableSourceVO> saveOrUpdate(@RequestBody JspayableSourceVO saveOrUpdateVO) {
    	JspayableSourceEntity entity = BeanMapper.map(saveOrUpdateVO, JspayableSourceEntity.class);
    	service.saveOrUpdate(entity, false);
    	JspayableSourceVO vo = BeanMapper.map(entity, JspayableSourceVO.class);
    	return CommonResponse.success("保存或修改单据成功！",vo);
    }

    /**
     * @Description queryDetail 查询详情
     * @param id
     */
    @RequestMapping(value = "/queryDetail", method = RequestMethod.GET)
    @ResponseBody
    public CommonResponse<JspayableSourceVO> queryDetail(Long id) {
    	JspayableSourceEntity entity = service.selectById(id);
    	JspayableSourceVO vo = BeanMapper.map(entity, JspayableSourceVO.class);
        return CommonResponse.success("查询详情数据成功！",vo);
    }

    /**
     * @Description delete 批量删除单据
     * @Param [ids]
     */
    @RequestMapping(value = "/delete", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<String> delete(@RequestBody List<JspayableSourceVO> vos) {
        if(ListUtil.isNotEmpty(vos)){
            for (JspayableSourceVO vo : vos) {
                // 参数是单据类型编码字符串 根据需求是否打开下面代码
                /* CommonResponse<String> resp = billTypeApi.checkQuote("billTypeCode", vo.getId());
                if(!resp.isSuccess()){
                    return CommonResponse.error("删除失败！"+resp.getMsg());
                }*/
            }
        }
        service.removeByIds(vos.stream().map(JspayableSourceVO::getId).collect(Collectors.toList()),true);
        return CommonResponse.success("删除成功！");
    }

    /**
     * @Description queryList 查询列表
     * @param param
     * @Return com.ejianc.framework.core.response.CommonResponse<java.lang.String>
     */
    @RequestMapping(value = "/queryList", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<IPage<JspayableSourceVO>> queryList(@RequestBody QueryParam param) {

        /** 模糊搜索配置字段示例 */
        List<String> fuzzyFields = param.getFuzzyFields();
        /** 租户隔离 */
        param.getParams().put("tenantId", new Parameter(QueryParam.EQ, InvocationInfoProxy.getTenantid()));

        /** 数据隔离 本下 没有组织orgId的删除下面代码-------------开始 */
        UserContext userContextCache =sessionManager.getUserContext();
        //当前应用有权限的根orgId，以逗号分割，可据此查询其本下数据，需判空
        String authOrgIds = userContextCache.getAuthOrgIds();
        List<OrgVO> orgVOList = null;
        if(StringUtils.isNotBlank(authOrgIds)){//移动端查询
            orgVOList = (List<OrgVO>) getRespData(iOrgApi.findChildrenByParentIds(Arrays.stream(authOrgIds.split(",")).map(Long::parseLong).collect(Collectors.toList())), true, "查询失败，获取当前本下组织信息失败。");
        }else {//pc端查询
            orgVOList = (List<OrgVO>) getRespData(iOrgApi.findChildrenByParentId(InvocationInfoProxy.getOrgId()), true, "查询失败，获取当前本下组织信息失败。");
        }
        //普通组织 id
        List<Long> commonOrgIds = new ArrayList<>();
        //项目部 id
        List<Long> departmentIds = new ArrayList<>();
        orgVOList.stream().forEach(org -> {
            if(5 == org.getOrgType()) {
                //项目部
                departmentIds.add(org.getId());
            } else {
                //普通组织
                commonOrgIds.add(org.getId());
            }
        });
        if(CollectionUtils.isNotEmpty(commonOrgIds)) {
            /** 要求主表有orgId字段，保存单据所属组织 */
            param.getParams().put("orgId", new Parameter(QueryParam.IN, commonOrgIds));
        } else if(CollectionUtils.isNotEmpty(departmentIds)) {
            /** 要求主表有projectDepartmentId字段，保存单据所属项目部 */
            param.getParams().put("orgId", new Parameter(QueryParam.IN, departmentIds));
        }
        /** 数据隔离 本下 没有组织orgId的删除上面代码-------------结束！！！ */

        IPage<JspayableSourceEntity> page = service.queryPage(param,false);
        IPage<JspayableSourceVO> pageData = new Page<>(page.getCurrent(), page.getSize(), page.getTotal());
  		pageData.setRecords(BeanMapper.mapList(page.getRecords(), JspayableSourceVO.class));

        return CommonResponse.success("查询列表数据成功！",pageData);
    }

    /**
     * 获取RPC数据
     * resp 返回值
     * isMustSuc 是否必须成功
     * errMsg 失败提示
     */
    private Object getRespData(CommonResponse<?> resp, boolean isMustSuc, String errMsg) {
        if(isMustSuc && !resp.isSuccess()) {
            throw new BusinessException(StringUtils.isNoneBlank(errMsg) ? errMsg : "调用Rpc服务失败");
        }
        return resp.getData();
    }


    /**
     * @Description 导出
     * @param param
     * @Return void
     */
    @RequestMapping(value = "/excelExport", method = RequestMethod.POST)
    @ResponseBody
    public void excelExport(@RequestBody QueryParam param, HttpServletResponse response) {
        /** 模糊搜索配置字段示例 */
        List<String> fuzzyFields = param.getFuzzyFields();
        param.getParams().put("tenant_id",new Parameter(QueryParam.EQ,InvocationInfoProxy.getTenantid()));
        param.setPageIndex(1);
        param.setPageSize(-1);
        /** 数据隔离 本下 没有组织orgId的删除下面代码 */
        param.getParams().put("orgId",new Parameter(QueryParam.IN,iOrgApi.findChildrenByParentId(InvocationInfoProxy.getOrgId()).getData().stream().map(OrgVO::getId).collect(Collectors.toList())));
        List<JspayableSourceEntity> list = service.queryList(param);
        //todo:字段翻译等等
        Map<String, Object> beans = new HashMap<>();
        beans.put("records", list);
        ExcelExport.getInstance().export("JspayableSource-export.xlsx", beans, response);
    }

    /**
     * @Description 参照
     * @param param
     * @Return void
     */
    @RequestMapping(value = "/refJspayableSourceData", method = RequestMethod.GET)
    @ResponseBody
    public CommonResponse<IPage<JspayableSourceVO>> refJspayableSourceData(@RequestParam Integer pageNumber, @RequestParam Integer pageSize,
                                                                        String condition,
                                                                        String searchObject,
                                                                        String searchText) {
        QueryParam param = new QueryParam();
        param.setPageSize(pageSize);
        param.setPageIndex(pageNumber);
        param.setSearchText(searchText);
        param.setSearchObject(searchObject);
        /** 租户隔离 */
        param.getParams().put("tenantId", new Parameter(QueryParam.EQ, InvocationInfoProxy.getTenantid()));
        if(StringUtils.isNotEmpty(condition)){
            /** 处理condition */
            JSONObject _con = JSONObject.parseObject(condition);
        }

        IPage<JspayableSourceEntity> page = service.queryPage(param,false);
        IPage<JspayableSourceVO> pageData = new Page<>(page.getCurrent(), page.getSize(), page.getTotal());
        pageData.setRecords(BeanMapper.mapList(page.getRecords(), JspayableSourceVO.class));

        return CommonResponse.success("查询参照数据成功！",pageData);
     }




    /**
     * @Description queryPayrollSourceDetail 工资单查看薪资来源
     * @param
     */
    @RequestMapping(value = "/queryPayrollSourceDetail", method = RequestMethod.GET)
    @ResponseBody
    public CommonResponse<List<SourceDetailVO>> queryPayrollSourceDetail(String idCard, String period, Long taxBillId, Long companyId) {


        //获取独立公司的下属组织
//        List<Long> companyIds = new ArrayList<>();
//        if (PayableController.zzyjOrgId.equals(companyId)){
//            companyIds = payableController.zzyjOrgIds();
//        }else {
//            CommonResponse<List<OrgVO>> childrenByParentId = iOrgApi.findChildrenByParentId(companyId);
//            if (childrenByParentId != null && childrenByParentId.getCode() == 0) {
//                List<OrgVO> data = childrenByParentId.getData();
//                if (CollectionUtils.isEmpty(data)) {
//                    throw new BusinessException("获取社保独立开户公司信息失败！");
//                }
//                companyIds = data.stream().map(OrgVO::getId).collect(Collectors.toList());
//            }
//        }


        Date month = new Date();
        DateFormat dateFormat = new SimpleDateFormat("yyyy-MM");
        try {
            month = dateFormat.parse(period);
        } catch (ParseException e) {
            e.printStackTrace();
        }
        List<SourceDetailVO> sourceDetailVOS = jspayableService.querySourceDetail(idCard, month,companyId);
        if (CollectionUtils.isNotEmpty(sourceDetailVOS) && sourceDetailVOS.size() > 0 && null != taxBillId){
            TaxEntity taxEntity = taxService.selectById(taxBillId);
            if (null != taxEntity && !(1 == taxEntity.getBillState() || 3 == taxEntity.getBillState())){
                sourceDetailVOS.forEach(e -> {
                    e.setTaxYfmsMny(e.getYfmsMny());
                });
            }
        }
        return CommonResponse.success("查询详情数据成功！", sourceDetailVOS);
    }

    /**
     * @Description updateTaxSource 个税计算修改来源数据
     */
    @RequestMapping(value = "/updateTaxSource", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<String> updateTaxSource(@RequestBody List<SourceDetailVO> vos) {
        if(CollectionUtils.isNotEmpty(vos)){
            for (SourceDetailVO sourceDetailVO : vos) {
                payableDetailService.update(new UpdateWrapper<PayableDetailEntity>().eq("id", sourceDetailVO.getId()).set("tax_yfms_mny", sourceDetailVO.getTaxYfmsMny()));
            }
            taxDetailService.update(new UpdateWrapper<TaxDetailEntity>().eq("id", vos.get(0).getTaxBillDetailId()).set("yfms_mny", vos.stream().filter(p -> p.getTaxYfmsMny() != null).map(SourceDetailVO::getTaxYfmsMny).reduce(BigDecimal.ZERO, BigDecimal::add)));
        }else {
            throw new BusinessException("子表不能为空!");
        }
        return CommonResponse.success("批量修改来源成功！");
    }
}

==> ejc-salary-impl-3.0.0-20250622.231317-149-sources.jar: com/ejianc/business/salary/controller/JspayableSourceController.java <==
package com.ejianc.business.salary.controller;

import java.io.Serializable;

import com.baomidou.mybatisplus.core.conditions.update.UpdateWrapper;
import com.ejianc.business.salary.bean.PayableDetailEntity;
import com.ejianc.business.salary.bean.TaxDetailEntity;
import com.ejianc.business.salary.bean.TaxEntity;
import com.ejianc.business.salary.service.*;
import com.ejianc.business.salary.vo.SourceDetailVO;
import com.ejianc.foundation.orgcenter.vo.OrgVO;
import com.ejianc.foundation.support.vo.BillCodeParam;
import com.ejianc.foundation.support.api.IBillCodeApi;
import com.ejianc.foundation.support.api.IBillTypeApi;
import com.ejianc.framework.core.exception.BusinessException;
import com.ejianc.framework.core.util.ComputeUtil;
import com.ejianc.framework.core.util.ExcelExport;
import org.apache.commons.lang3.StringUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import java.math.BigDecimal;
import java.text.DateFormat;
import java.text.ParseException;
import java.text.SimpleDateFormat;
import java.util.*;
import java.util.stream.Collectors;
import com.alibaba.fastjson.JSONObject;
import org.springframework.stereotype.Controller;
import org.springframework.web.bind.annotation.*;
import org.apache.commons.collections.CollectionUtils;
import javax.servlet.http.HttpServletResponse;

import com.ejianc.foundation.orgcenter.api.IOrgApi;
import com.ejianc.framework.core.response.CommonResponse;
import org.springframework.beans.factory.annotation.Autowired;
import com.ejianc.framework.core.context.InvocationInfoProxy;
import com.ejianc.framework.core.kit.mapper.BeanMapper;
import com.ejianc.framework.core.kit.collection.ListUtil;
import com.ejianc.framework.auth.session.SessionManager;
import com.ejianc.framework.auth.session.UserContext;

import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.ejianc.framework.core.response.Parameter;
import com.ejianc.framework.core.response.QueryParam;

import com.ejianc.business.salary.bean.JspayableSourceEntity;
import com.ejianc.business.salary.vo.JspayableSourceVO;

/**
 * 应发工资明细来源
 *
 * @author generator
 *
 */
@Controller
@RequestMapping("jspayableSource")
public class JspayableSourceController implements Serializable {
	private static final long serialVersionUID = 1L;

    private Logger logger = LoggerFactory.getLogger(this.getClass());

    @Autowired
    private IBillTypeApi billTypeApi;
    @Autowired
    private IBillCodeApi billCodeApi;
    @Autowired
    private IOrgApi iOrgApi;

    private static final String BILL_CODE = "Invoice_Open_Apply_Code";//此处需要根据实际修改

    @Autowired
    private IJspayableSourceService service;

    @Autowired
    private SessionManager sessionManager;



    @Autowired
    private IJspayableService jspayableService;

    @Autowired
    private IPayableDetailService payableDetailService;
    @Autowired
    private ITaxService taxService;
    @Autowired
    private ITaxDetailService taxDetailService;
    @Autowired
    private PayableController payableController;

    /**
     * @Description saveOrUpdate 新增或者修改
     */
    @RequestMapping(value = "/saveOrUpdate", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<JspayableSourceVO> saveOrUpdate(@RequestBody JspayableSourceVO saveOrUpdateVO) {
    	JspayableSourceEntity entity = BeanMapper.map(saveOrUpdateVO, JspayableSourceEntity.class);
    	service.saveOrUpdate(entity, false);
    	JspayableSourceVO vo = BeanMapper.map(entity, JspayableSourceVO.class);
    	return CommonResponse.success("保存或修改单据成功！",vo);
    }

    /**
     * @Description queryDetail 查询详情
     * @param id
     */
    @RequestMapping(value = "/queryDetail", method = RequestMethod.GET)
    @ResponseBody
    public CommonResponse<JspayableSourceVO> queryDetail(Long id) {
    	JspayableSourceEntity entity = service.selectById(id);
    	JspayableSourceVO vo = BeanMapper.map(entity, JspayableSourceVO.class);
        return CommonResponse.success("查询详情数据成功！",vo);
    }

    /**
     * @Description delete 批量删除单据
     * @Param [ids]
     */
    @RequestMapping(value = "/delete", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<String> delete(@RequestBody List<JspayableSourceVO> vos) {
        if(ListUtil.isNotEmpty(vos)){
            for (JspayableSourceVO vo : vos) {
                // 参数是单据类型编码字符串 根据需求是否打开下面代码
                /* CommonResponse<String> resp = billTypeApi.checkQuote("billTypeCode", vo.getId());
                if(!resp.isSuccess()){
                    return CommonResponse.error("删除失败！"+resp.getMsg());
                }*/
            }
        }
        service.removeByIds(vos.stream().map(JspayableSourceVO::getId).collect(Collectors.toList()),true);
        return CommonResponse.success("删除成功！");
    }

    /**
     * @Description queryList 查询列表
     * @param param
     * @Return com.ejianc.framework.core.response.CommonResponse<java.lang.String>
     */
    @RequestMapping(value = "/queryList", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<IPage<JspayableSourceVO>> queryList(@RequestBody QueryParam param) {

        /** 模糊搜索配置字段示例 */
        List<String> fuzzyFields = param.getFuzzyFields();
        /** 租户隔离 */
        param.getParams().put("tenantId", new Parameter(QueryParam.EQ, InvocationInfoProxy.getTenantid()));

        /** 数据隔离 本下 没有组织orgId的删除下面代码-------------开始 */
        UserContext userContextCache =sessionManager.getUserContext();
        //当前应用有权限的根orgId，以逗号分割，可据此查询其本下数据，需判空
        String authOrgIds = userContextCache.getAuthOrgIds();
        List<OrgVO> orgVOList = null;
        if(StringUtils.isNotBlank(authOrgIds)){//移动端查询
            orgVOList = (List<OrgVO>) getRespData(iOrgApi.findChildrenByParentIds(Arrays.stream(authOrgIds.split(",")).map(Long::parseLong).collect(Collectors.toList())), true, "查询失败，获取当前本下组织信息失败。");
        }else {//pc端查询
            orgVOList = (List<OrgVO>) getRespData(iOrgApi.findChildrenByParentId(InvocationInfoProxy.getOrgId()), true, "查询失败，获取当前本下组织信息失败。");
        }
        //普通组织 id
        List<Long> commonOrgIds = new ArrayList<>();
        //项目部 id
        List<Long> departmentIds = new ArrayList<>();
        orgVOList.stream().forEach(org -> {
            if(5 == org.getOrgType()) {
                //项目部
                departmentIds.add(org.getId());
            } else {
                //普通组织
                commonOrgIds.add(org.getId());
            }
        });
        if(CollectionUtils.isNotEmpty(commonOrgIds)) {
            /** 要求主表有orgId字段，保存单据所属组织 */
            param.getParams().put("orgId", new Parameter(QueryParam.IN, commonOrgIds));
        } else if(CollectionUtils.isNotEmpty(departmentIds)) {
            /** 要求主表有projectDepartmentId字段，保存单据所属项目部 */
            param.getParams().put("orgId", new Parameter(QueryParam.IN, departmentIds));
        }
        /** 数据隔离 本下 没有组织orgId的删除上面代码-------------结束！！！ */

        IPage<JspayableSourceEntity> page = service.queryPage(param,false);
        IPage<JspayableSourceVO> pageData = new Page<>(page.getCurrent(), page.getSize(), page.getTotal());
  		pageData.setRecords(BeanMapper.mapList(page.getRecords(), JspayableSourceVO.class));

        return CommonResponse.success("查询列表数据成功！",pageData);
    }

    /**
     * 获取RPC数据
     * resp 返回值
     * isMustSuc 是否必须成功
     * errMsg 失败提示
     */
    private Object getRespData(CommonResponse<?> resp, boolean isMustSuc, String errMsg) {
        if(isMustSuc && !resp.isSuccess()) {
            throw new BusinessException(StringUtils.isNoneBlank(errMsg) ? errMsg : "调用Rpc服务失败");
        }
        return resp.getData();
    }


    /**
     * @Description 导出
     * @param param
     * @Return void
     */
    @RequestMapping(value = "/excelExport", method = RequestMethod.POST)
    @ResponseBody
    public void excelExport(@RequestBody QueryParam param, HttpServletResponse response) {
        /** 模糊搜索配置字段示例 */
        List<String> fuzzyFields = param.getFuzzyFields();
        param.getParams().put("tenant_id",new Parameter(QueryParam.EQ,InvocationInfoProxy.getTenantid()));
        param.setPageIndex(1);
        param.setPageSize(-1);
        /** 数据隔离 本下 没有组织orgId的删除下面代码 */
        param.getParams().put("orgId",new Parameter(QueryParam.IN,iOrgApi.findChildrenByParentId(InvocationInfoProxy.getOrgId()).getData().stream().map(OrgVO::getId).collect(Collectors.toList())));
        List<JspayableSourceEntity> list = service.queryList(param);
        //todo:字段翻译等等
        Map<String, Object> beans = new HashMap<>();
        beans.put("records", list);
        ExcelExport.getInstance().export("JspayableSource-export.xlsx", beans, response);
    }

    /**
     * @Description 参照
     * @param param
     * @Return void
     */
    @RequestMapping(value = "/refJspayableSourceData", method = RequestMethod.GET)
    @ResponseBody
    public CommonResponse<IPage<JspayableSourceVO>> refJspayableSourceData(@RequestParam Integer pageNumber, @RequestParam Integer pageSize,
                                                                        String condition,
                                                                        String searchObject,
                                                                        String searchText) {
        QueryParam param = new QueryParam();
        param.setPageSize(pageSize);
        param.setPageIndex(pageNumber);
        param.setSearchText(searchText);
        param.setSearchObject(searchObject);
        /** 租户隔离 */
        param.getParams().put("tenantId", new Parameter(QueryParam.EQ, InvocationInfoProxy.getTenantid()));
        if(StringUtils.isNotEmpty(condition)){
            /** 处理condition */
            JSONObject _con = JSONObject.parseObject(condition);
        }

        IPage<JspayableSourceEntity> page = service.queryPage(param,false);
        IPage<JspayableSourceVO> pageData = new Page<>(page.getCurrent(), page.getSize(), page.getTotal());
        pageData.setRecords(BeanMapper.mapList(page.getRecords(), JspayableSourceVO.class));

        return CommonResponse.success("查询参照数据成功！",pageData);
     }




    /**
     * @Description queryPayrollSourceDetail 工资单查看薪资来源
     * @param
     */
    @RequestMapping(value = "/queryPayrollSourceDetail", method = RequestMethod.GET)
    @ResponseBody
    public CommonResponse<List<SourceDetailVO>> queryPayrollSourceDetail(String idCard, String period, Long taxBillId, Long companyId) {


        //获取独立公司的下属组织
//        List<Long> companyIds = new ArrayList<>();
//        if (PayableController.zzyjOrgId.equals(companyId)){
//            companyIds = payableController.zzyjOrgIds();
//        }else {
//            CommonResponse<List<OrgVO>> childrenByParentId = iOrgApi.findChildrenByParentId(companyId);
//            if (childrenByParentId != null && childrenByParentId.getCode() == 0) {
//                List<OrgVO> data = childrenByParentId.getData();
//                if (CollectionUtils.isEmpty(data)) {
//                    throw new BusinessException("获取社保独立开户公司信息失败！");
//                }
//                companyIds = data.stream().map(OrgVO::getId).collect(Collectors.toList());
//            }
//        }


        Date month = new Date();
        DateFormat dateFormat = new SimpleDateFormat("yyyy-MM");
        try {
            month = dateFormat.parse(period);
        } catch (ParseException e) {
            e.printStackTrace();
        }
        List<SourceDetailVO> sourceDetailVOS = jspayableService.querySourceDetail(idCard, month,companyId);
        if (CollectionUtils.isNotEmpty(sourceDetailVOS) && sourceDetailVOS.size() > 0 && null != taxBillId){
            TaxEntity taxEntity = taxService.selectById(taxBillId);
            if (null != taxEntity && !(1 == taxEntity.getBillState() || 3 == taxEntity.getBillState())){
                sourceDetailVOS.forEach(e -> {
                    e.setTaxYfmsMny(e.getYfmsMny());
                });
            }
        }
        return CommonResponse.success("查询详情数据成功！", sourceDetailVOS);
    }

    /**
     * @Description updateTaxSource 个税计算修改来源数据
     */
    @RequestMapping(value = "/updateTaxSource", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<String> updateTaxSource(@RequestBody List<SourceDetailVO> vos) {
        if(CollectionUtils.isNotEmpty(vos)){
            for (SourceDetailVO sourceDetailVO : vos) {
                payableDetailService.update(new UpdateWrapper<PayableDetailEntity>()
                        .eq("id", sourceDetailVO.getId())
                        .set("yfmscw_mny", sourceDetailVO.getTaxYfmscwMny())
                        .set("yfjscw_mny", sourceDetailVO.getTaxYfjscwMny())
                );

            }
            TaxDetailEntity taxDetailEntity = taxDetailService.selectById(vos.get(0).getTaxBillDetailId());
            BigDecimal yfmscwMny = vos.stream().filter(p -> p.getTaxYfmscwMny() != null).map(SourceDetailVO::getTaxYfmscwMny).reduce(BigDecimal.ZERO, BigDecimal::add);
            BigDecimal yfjscwMny = vos.stream().filter(p -> p.getTaxYfjscwMny() != null).map(SourceDetailVO::getTaxYfjscwMny).reduce(BigDecimal.ZERO, BigDecimal::add);


            taxDetailEntity.setYfmscwMny(yfmscwMny);
            taxDetailEntity.setYfjscwMny(yfjscwMny);

            //本期收入 = 应发工资 + 应发计税 + 应发计税1
            taxDetailEntity.setYfmsSalaryMny( ComputeUtil.safeAdd(null != taxDetailEntity.getYfSalaryMny() ? taxDetailEntity.getYfSalaryMny() : BigDecimal.ZERO, null != taxDetailEntity.getYfjsMny() ? taxDetailEntity.getYfjsMny() : BigDecimal.ZERO, null != yfjscwMny ? yfjscwMny : BigDecimal.ZERO));
            taxDetailService.saveOrUpdate(taxDetailEntity);
//            taxDetailService.update(new UpdateWrapper<TaxDetailEntity>()
//                    .eq("id", vos.get(0).getTaxBillDetailId())
//                    .set("yfmscw_mny", vos.stream().filter(p -> p.getTaxYfmscwMny() != null).map(SourceDetailVO::getTaxYfmscwMny).reduce(BigDecimal.ZERO, BigDecimal::add))
//                    .set("yfjscw_mny", vos.stream().filter(p -> p.getTaxYfjscwMny() != null).map(SourceDetailVO::getTaxYfjscwMny).reduce(BigDecimal.ZERO, BigDecimal::add))
//            );
         }else {
            throw new BusinessException("子表不能为空!");
        }
        return CommonResponse.success("批量修改来源成功！");
    }
}
